@@ -11,7 +11,7 @@ import ForwardDiff
 function _linspace(a::Float64, b::Float64, n::Int)
     intv = (b - a) / (n - 1)
     r = Vector{Float64}(undef, n)
-    @inbounds for i = 1:n
+    for i = 1:n
         r[i] = a + (i-1) * intv
     end
     r[n] = b
@@ -171,7 +171,7 @@ function test_samples(s::Sampleable{Univariate, Discrete},      # the sampleable
     cnts = zeros(Int, m)
     cnts_sc = zeros(Int, m)
     for i = 1:n
-        @inbounds si = samples[i]
+        si = samples[i]
         if rmin <= si <= rmax
             cnts[si - rmin + 1] += 1
         else
@@ -179,7 +179,7 @@ function test_samples(s::Sampleable{Univariate, Discrete},      # the sampleable
                 throw(DomainError(si, "sample generated by `rand(s, n)` is out of valid range [$vmin, $vmax]."))
         end
 
-        @inbounds si_sc = samples3[i]
+        si_sc = samples3[i]
         if rmin <= si_sc <= rmax
             cnts_sc[si_sc - rmin + 1] += 1
         else
@@ -297,10 +297,10 @@ function test_samples(s::Sampleable{Univariate, Continuous},    # the sampleable
 
     # check whether all samples are in the valid range
     for i = 1:n
-        @inbounds si = samples[i]
+        si = samples[i]
         vmin <= si <= vmax ||
             throw(DomainError(si, "sample generated by `rand(s, n)` is out of valid range [$vmin, $vmax]."))
-        @inbounds si_sc = samples3[i]
+        si_sc = samples3[i]
         vmin <= si_sc <= vmax ||
             throw(DomainError(si, "sample generated by `[rand(s) for _ in 1:n]` is out of valid range [$vmin, $vmax]."))
     end
